#
# spec file for package linphone
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ldaplibdir %{buildroot}%{_libexecdir}/%{name}
#use_system_ldap set to 0 because liblinphone 5.x fails to build with system ldap
%define use_system_ldap 0
%define static_ldap 1
%if !0%{?static_ldap}
%define __provides_exclude ^(libldap\\.so.*|liblber\\.so.*)$
%define __requires_exclude ^(libldap\\.so.*|liblber\\.so.*)$
%endif
%define sover   10
Name:           linphone
Version:        5.2.10
Release:        bp155.1.25
Summary:        Web Phone
License:        AGPL-3.0-or-later
Group:          Productivity/Telephony/SIP/Clients
URL:            https://linphone.org/technical-corner/liblinphone/
Source:         https://gitlab.linphone.org/BC/public/liblinphone/-/archive/%{version}/liblinphone-%{version}.tar.bz2
Source1:        %{name}-manual.tar.bz2
Source3:        https://gitlab.linphone.org/BC/public/external/openldap/-/archive/bc/openldap-bc.tar.bz2
# PATCH-FIX-OPENSUSE linphone-fix-pkgconfig.patch sor.alexei@meowr.ru -- Install linphone.pc.
Patch0:         linphone-fix-pkgconfig.patch
# PATCH-FEATURE-OPENSUSE linphone-build-readline.patch sor.alexei@meowr.ru -- Add the ability to compile with readline to the build system.
Patch1:         linphone-build-readline.patch
# PATCH-FIX-UPSTREAM
Patch2:         reproducible.patch
# PATCH-FIX-OPENSUSE linphone-link-soci-sqlite3.patch -- force linking to libsoci_sqlite3 so that RPM finds the requirement boo#1140595 -- code@bnavigator.de
Patch3:         linphone-link-soci-sqlite3.patch
# PATCH-FIX-OPENSUSE linphone-build-jsoncpp.patch -- use pkgconfig to find jsoncpp and link against jsoncpp, not jsoncpp_object
Patch4:         linphone-build-jsoncpp.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  jsoncpp-devel
BuildRequires:  libeXosip2-devel
%if 0%{?suse_version}
BuildRequires:  libgsm-devel
%else
BuildRequires:  gsm-devel
%endif
BuildRequires:  lime-devel >= 5.0.0
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  python3-pystache
BuildRequires:  python3-six
%if 0%{?suse_version}
BuildRequires:  python3-xml
%endif
BuildRequires:  readline-devel
%if 0%{?suse_version}
BuildRequires:  sgmltool
%else
BuildRequires:  linuxdoc-tools
%endif
BuildRequires:  soci-devel
BuildRequires:  soci-sqlite3-devel
BuildRequires:  xsd
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bctoolbox) >= 5.0.0
BuildRequires:  pkgconfig(belcard) >= 4.5.0
BuildRequires:  pkgconfig(belle-sip) >= 5.0.0
BuildRequires:  pkgconfig(libavcodec) >= 51.0.0
BuildRequires:  pkgconfig(libbzrtp) >= 5.0.0
BuildRequires:  pkgconfig(libosip2)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libswscale) >= 0.7.0
BuildRequires:  pkgconfig(libturbojpeg)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(libv4l2) >= 0.8.4
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mediastreamer) >= 5.0.0
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(ortp) >= 5.0.0
BuildRequires:  pkgconfig(speex) >= 1.1.6
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(zxing)
%if 0%{?use_system_ldap}
%if 0%{?suse_version}
BuildRequires:  openldap2-devel
%else
BuildRequires:  openldap-devel
%endif
%else
%if 0%{?suse_version}
BuildRequires:  db-devel
%else
BuildRequires:  libdb-devel
%endif
BuildRequires:  openslp-devel
%endif
%if 0%{?fedora}
BuildRequires:  pkgconfig(openssl)
%endif
BuildRequires:  chrpath

%description
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%package cli
Summary:        Web Phone Command Line Interface
Group:          Productivity/Telephony/SIP/Clients
Requires:       lib%{name}-data = %{version}

%description cli
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains the command line interface.

%package -n lib%{name}%{sover}
Summary:        Web Phone library
Group:          Productivity/Telephony/SIP/Clients
%if 0%{?suse_version}
Recommends:     lib%{name}-lang
%endif
Provides:       lib%{name} = %{version}

%description -n lib%{name}%{sover}
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains a library.

%if 0%{?suse_version}
%lang_package -n lib%{name}
%endif

%package -n lib%{name}++%{sover}
Summary:        Web Phone C++ library
Group:          Productivity/Telephony/SIP/Clients

%description -n lib%{name}++%{sover}
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains a C++ library.

%package -n lib%{name}-data
Summary:        Web Phone data files
Group:          Productivity/Telephony/SIP/Clients
BuildArch:      noarch

%description -n lib%{name}-data
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains data files such as sounds.

%package -n lib%{name}-devel
Summary:        Web Phone Development files
Group:          Development/Languages/C and C++
Requires:       glibc-devel
Requires:       lib%{name}%{sover} = %{version}
Requires:       lib%{name}++%{sover} = %{version}
Requires:       lib%{name}-data = %{version}
Requires:       libeXosip2-devel
Requires:       libosip2-devel
Requires:       soci-devel
Requires:       soci-sqlite3-devel
Requires:       pkgconfig(alsa)
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(libavcodec) >= 51.0.0
Requires:       pkgconfig(libswscale) >= 0.7.0
Requires:       pkgconfig(speex)
# linphone-devel was last used in openSUSE Leap 42.3.
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}

%description -n lib%{name}-devel
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%prep
%autosetup -n liblinphone-%{version} -p1
%setup -q -n liblinphone-%{version} -D -T -a 1
%if 0%{?fedora}
# patch deprecated python open mode
sed -i "s|mode='rU'|mode='r'|" wrappers/cpp/genwrapper.py
# patch ssl sasl - extends linphone-build-jsoncpp.patch
sed -i "s|jsoncpp)|jsoncpp ssl sasl2)|g" src/CMakeLists.txt
sed -i "s|jsoncpp)|jsoncpp ssl sasl2)|g" tester/CMakeLists.txt
%endif

%build
%if !0%{?use_system_ldap}
#START build belledonne's libldap
mkdir aux
tar fx %{SOURCE3} -C aux
cd aux/openldap-bc
LDFLAGS="-Wl,-rpath,%ldaplibdir" ./configure \
%if 0%{?static_ldap}
  --enable-static=yes \
  --enable-shared=no \
  --with-pic         \
%else
  --enable-static=no \
%endif
  --enable-slapd=no  \
  --enable-wrappers=no \
  --enable-spasswd   \
  --with-tls=openssl \
  --with-cyrus-sasl  \
  --enable-crypt     \
  --enable-ipv6=yes  \
  --enable-rewrite   \
  --enable-slp       \
  --enable-lmpasswd  \
  --with-yielding-select \
  --prefix=$PWD/..   \
  --libdir=%{ldaplibdir}
make depend
make %{?_smp_mflags}
# do a preliminary install, because libldap is needed to build liblinphone
make install
cd ../..
#END build belledonne's libldap
#find and use belledonne's libldap
sed -i "/OPENLDAP_INCLUDE_DIRS/,/LDAP_LIB/s@\${CMAKE_INSTALL_PREFIX}@$PWD/aux@;s@\${CMAKE_INSTALL_PREFIX}@%{ldaplibdir}@;s@include/openldap@include@" cmake/FindOpenLDAP.cmake
%endif
%cmake \
  -DPYTHON_EXECUTABLE="%{_bindir}/python3" \
  -DENABLE_CXX_WRAPPER=ON      \
%if !0%{?use_system_ldap}
%if 0%{?suse_version}
  -DOPENLDAP_INCLUDE_DIRS=$PWD/../aux/include \
%else
  -DOPENLDAP_INCLUDE_DIRS=$PWD/aux/include \
  -DCMAKE_INSTALL_LIBDIR=lib64 \
%endif
%if 0%{?static_ldap}
  -DLDAP_LIB=%{ldaplibdir}/libldap.a \
%else
  -DLDAP_LIB=%{ldaplibdir}/libldap.so \
%endif
  -DCMAKE_SHARED_LINKER_FLAGS="-Wl,-rpath,%{ldaplibdir}" \
%endif
  -DENABLE_DOC=ON              \
  -DCMAKE_BUILD_TYPE=Release   \
  -DENABLE_ROOTCA_DOWNLOAD=OFF \
  -DENABLE_ZRTP=ON             \
  -DENABLE_LDAP=ON             \
  -DENABLE_TOOLS=OFF           \
  -DENABLE_STRICT=OFF          \
  -DENABLE_STATIC=OFF          \
  -DENABLE_FLEXIAPI=OFF        \
%if 0%{?suse_version} > 1500
  -DENABLE_QRCODE=OFF          \
%endif
  -DCMAKE_LINK_WHAT_YOU_USE=ON

%cmake_build

%install
%if !0%{?use_system_ldap}
#START reinstall belledonne's libldap
cd aux/openldap-bc
make install
cd ../..
cp aux/openldap-bc/LICENSE LICENSE.openldap
#END reinstall belledonne's libldap
%endif
%cmake_install
%if !0%{?use_system_ldap}
%if !0%{?static_ldap}
#remove unnecessary files
rm %{ldaplibdir}/*.{la,so}
#fix rpath in openldap libs and make them executable
find %{ldaplibdir} -type f -exec chrpath -r %{_libexecdir}/%{name} {} \; -exec chmod a+x {} \;
#fix rpath in liblinphone
find %{buildroot}%{_libdir} -type f -name "liblinphone*" -exec chrpath -r %{_libexecdir}/%{name} {} \;
# Remove openldap pkgconfig files.
rm -r %{ldaplibdir}/pkgconfig
%else
rm -r %{ldaplibdir}
%endif
%endif

chrpath -d %{buildroot}%{_libdir}/lib%{name}.so.%{sover}* %{buildroot}%{_libdir}/lib%{name}++.so.%{sover}*
chrpath -d %{buildroot}%{_bindir}/{linphone-daemon-pipetest,linphone-daemon,groupchat_benchmark,linphonec,linphonecsh,liblinphone_tester}
%if !0%{?use_system_ldap} && 0%{?fedora}
# ldaplibdir will remain in lib, disable check-buildroot for Fedora
export QA_SKIP_BUILD_ROOT=0
%endif

# Install the manual.
%if 0%{?suse_version}
mkdir -p %{buildroot}%{_datadir}/gnome/help/
cp -a %{name} %{buildroot}%{_datadir}/gnome/help/%{name}/
%find_lang %{name}
%endif
%fdupes %{buildroot}%{_datadir}/

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig
%post -n lib%{name}++%{sover} -p /sbin/ldconfig
%postun -n lib%{name}++%{sover} -p /sbin/ldconfig

%files cli
%{_bindir}/%{name}c*
%{_bindir}/%{name}-daemon*

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}.so.%{sover}*
%if !0%{?use_system_ldap}
%if !0%{?static_ldap}
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/
%endif
%endif

%if 0%{?suse_version}
%files -n lib%{name}-lang -f %{name}.lang
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%endif

%files -n lib%{name}++%{sover}
%{_libdir}/lib%{name}++.so.%{sover}*

%files -n lib%{name}-data
%license LICENSE.txt
%if !0%{?use_system_ldap}
%license LICENSE.openldap
%endif
%doc CHANGELOG.md README.md
%{_datadir}/%{name}/
%{_datadir}/sounds/%{name}/
%{_datadir}/belr/grammars/*_grammar

%files -n lib%{name}-devel
%{_includedir}/%{name}*/
%{_bindir}/lib%{name}_tester
%{_bindir}/groupchat_benchmark
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}++.so
%{_datadir}/liblinphone_tester/
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/Linphone/
%{_datadir}/LinphoneCxx/
%{_datadir}/doc/lib%{name}-5.2.0/

%changelog
* Mon Feb  6 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.10
-Disable QRCode image generation for tumbleweed
  * liblinphone is not currently compatible with zxing-cpp 2.0.0
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.10
- Update to version 5.2.10:
  * Video conferencing feature with "mosaic" and "active speaker + thumbnails" layouts
  * Added conferencing scheduling API
  * Support for post-quantum robust encryption for ZRTP calls
  * Rtp bundle can be enabled per LinphoneAccount
  * New APIs on Friend object to be able to set more info
  * QRCode image generation
  * Licence becomes AGPLv3
* Sat Sep 10 2022 thod_@gmx.de
- Update to version 5.1.58
  https://gitlab.linphone.org/BC/public/liblinphone/-/tags/5.1.58
* Sun Aug 14 2022 thod_@gmx.de
- Remove RPATH (instead of ingnore) to be able to build on Fedora (no lang)
* Fri Jul 15 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 5.1.48.
  * Improved how device ringtone is obtained
  * Fixed DNS servers list not updated when network changes
  * Set ConferenceId also if conference event package is not enabled
  * Make DTLS-SRTP to start immediately after the default candidate pair is verified by ICE.
  * increase tests timeout
  * Fixed audio echo canceller calibration not being done using speaker on Android
  * Fixed audio focus not taken when doing echo canceller calibration if it is disabled for calls
  * Fix accepting an sdp with mid but no correponding extmap attribute when it shouldn't
- Use rpmlintrc to ignore RPATH because the environment variable does not work anymore on TW.
- Remove fix that doesn’t seem to be necessary anymore.
* Wed Jun  8 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.1.42
- Update to version 5.1.42:
  * Fixed incoming call ringtone being played even if device is in do not disturb mode
  * Fixed call log duration not available in End state
  * Fixed call duration not returning 0 if call didn't connect
  * Fixed BufferedReader not closed
  * Fixed adding a phone number with an invalid label to a Friend
* Sat May  7 2022 Giacomo Comes <gcomes.obs@gmail.com>
- Update to version 5.1.24:
  * LinphoneRecorder API added to record voice messages
  * A recommended video definitions list that filter the supported video definitions list.
  * LDAP connectivity into LinphoneMagicSearch API (to lookup contacts by number or name).
  * Java wrapper no longer catches app exceptions that happen in listeners.
  * linphone_core_enable_mic() is changed to be persistent accross calls and conference.
  * To protect against "SIP digest leak", MD5 and digestion without qop=auth can be disabled
    by configuration
- build static libldap boo#1198407
- revert license tag change
* Wed Apr 27 2022 Andreas Stieger <andreas.stieger@gmx.de>
- do not add bundled libraries as rpm required libs boo#1198407
* Fri Apr 22 2022 Andreas Stieger <andreas.stieger@gmx.de>
- do not add bundled libraries as rpm provided libs boo#1198407
* Mon Mar  7 2022 Lukas Müller <expeehaa@outlook.com>
- Update to version 5.0.70:
  * add tests for register with unresponsive server
  * Add telephone event payload from the core if result is empty aka : the first.
  * Repair tests failing due to missing root certificate after changing certificate on linphone.or
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * Fix linphone_core_enable_mic() not working for a local conference
  * Fix stream direction in remote params
  * fix start srtp dtls immediately
  * Fix non-working tunnel for incoming calls made without ICE
  * Keep ringing audio focus for incoming early media call as soundcard will use RING modei
  * Avoid notify ringing of in IncomingEarlyMedia state in order to not send 180 after 183
  * Write down call decline reasons into test
  * Added config setting to disable audio focus requests
  * Fix issue when soundcard may not be used after early media when handling multiple calls
  * Do not connect audio to conference during early media
  * fix crash get address when participants list is empty
  * enable mic by default
- fix license tag
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * Update log file only if enabled to avoid unwanted file creation
  * Use belle_sdp_attribute_parse() so that headers are parsed with the correct type
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to 5.0.49:
  * Fix crash when configuring tones while core is not yet started
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.47
- Update to 5.0.47:
  * Fix broken reading of video capture device from config file
  * Fix crash on PUBLISH when SIP-Etag is missing
  * Correctly route sound to speaker after early media and when cancelling call
  * Attempt to make local network permission detection more reliable
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to 5.0.36:
  * Use UTF8 instead of locale in chat message modifiers`
  * Fix bad chat room when creating a call
  * Crash on ec-calibration : Use tone sent callback only on MS_DTMF_GEN_EVENT
  * Added missing conference APIs
  * Play ring tone only if tone indications are enabled
  * Fix tonemanager on infinite rings and wrong ring type
  * fix crash of kickOffConnectivity
  * Add option to deactivate potentially weak digest authentication schemes
  * Fix issue when receiving an INVITE with ICE and rtcp-mux
  * Fix call repair in case of multi account
  * Fix regression with ICE not setting candidates correctly for completed check-lists
  * Improve reliability of account creation by increasing account creation timeout to 30s
  * Change contact address if call in IncomingReceived state is added to conference
  * fix crash when session refresh after BYE received
  * Repair streaming from file feature of AudioStream/VideoStream
  * Fixed error logs showing CoreManager's core being const
  * Logging facility optimization
  * Fix bug with ChatRoomParams::isGroup() erroneously returning true for some basic chatrooms
  * Count unread chat messages in all Chat Rooms with a weak address testing
  * avoid to downgrade chat message participant state and add unitest
  * Stop audio stream when setting new device
    This fix allow changing device on Desktop while ringback
  * Audio : Allow setting NULL device (case of no cards available)
  * Fixed call to content.isFileEncrypted() on a FileTransferContent
  * Fixed mic gain
- Update to 5.0.0:
  * Support of Capability Negociation framework - RFC5939
    limited to media encryption choice (None, SRTP, DTLS-SRTP, ZRTP)
  * New API to manage SIP accounts: LinphoneAccount and LinphoneAccountParams
    replacing LinphoneProxyConfig which is now deprecated.
    LinphoneProxyConfig remains fully usable for backward compatibility with previous version.
  * New implementation of LinphoneAccountCreator relying on http REST API.
  * Added LDAP contact provider API integrated with LinphoneMagicSearch
  * Added asynchronous API to the LinphoneMagicSearch API (for contact searching).
  * Fixed erroneous ICE ufrag and passwd parameters sent in reINVITE while ICE
    was refused previously.
  * Fixed swift and C# wrappers corner-case usage issues.
- Build and use Belledonne's version of libldap
- delete build-liblinphone4-with-mediastreamer5.patch
- add linphone-build-jsoncpp.patch
- add BuildRequires:  jsoncpp-devel
* Mon Sep 27 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.5.25
- removed unnecessary baselibs.conf
* Fri Jul 30 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.5.25
- Update to 4.5.25:
  * Fix an issue with ICE ufrag and passwd sent erroneously during reINVITE
  * Fixed crash in message tests suite
  * Prevent crash when receiving non-ephemeral message with linphone cpim namespace
  * Fixed mic gain
- add build-liblinphone4-with-mediastreamer5.patch
* Sun Jul  4 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.5.21
- fix several RPMLINT warning
- Update to 4.5.21:
  * Improved metered active network while in background check,
    update network reachability when background/foreground
    state changes
  * Fix setting output audio device that was based on ringer device
    on specific call state
  * Handle situation where a participant with an invalid address is
    added to a chat room
  * Fix conference server memory leak
- Update to 4.5.15:
  * Don't play the local ringtone when callkit is used
  * fix memory leak
  * Fix : on incoming call, do not start the ring tone if the
    call's state has been modified by listeners
- Update to 4.5.10:
  * Fix Callkit audio bug producing only with some old ios devices
  * Stop file player to play a file when stopping tone is requested
- Update to 4.5.7:
  * Fix bug causing undesired transition from Paused to
    StreamsRunning state in case of incoming UPDATE request
  * Proper CoreManager destruction
  * Abort push notification init on Android if gcm_defaultSenderId
    resource isn't found
  * Fix lime enabled device receiving an INVITE without SDP crash
  * Improved how we detect if firebase is available or not
  * Fixed ringing during early media for Android if native ringing
    enabled
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3:
  * CoreService class for Android can make the device vibrate while
    incoming call is ringing.
  * Audio conference API improved: distribution of participant list
    over RFC4575 SUBSCRIBE/NOTIFY.
  * enterForeground() and enterBackground() automatically called
    (iOS and Android).
  * auto acquire and release of audio focus for Android.
  * Core.iterate() is being called automatically internally for
    Android, it is no longer needed to create a timer in the
    application to call it.
  * New audio routes API to choose which device use to capture &
    play audio (Android & iOS). The application can manage
  * audio route changes (bluetooth, speaker, earpiece) throug
    liblinphone's API.
  * Added API to play user's ringtone instead of default ringtone
    for Android.
  * Added callback to notify a message is about to be sent.
  * iOS: added linphone_core_configure_audio_session() to be called
    when used with Callkit
  * client-based video conference in active speaker switching mode
    (beta feature).
  * Warning: some function parameters have been renamed for
    consistency, which modified the Swift API (where parameter
    names are part of the ABI). As a result, adjustements in
    applications are expected when migrating a swift app based on
    liblinphone from 4.4 to 4.5.
  * Improved Android network manager.
  * To make it consistent with other liblinphone's object,
    linphone_core_create_subscribe(),
    linphone_core_create_subscribe2(),
    linphone_core_create_publish() now give ownership of the
    returned LinphoneEvent, which means that it is no longer need
    to call linphone_event_ref() after calling these functions. As
    a consequence, an application not using linphone_event_ref()
    should now use linphone_event_unref() when the LinphoneEvent is
    no longer used, otherwise it will create a memory leak.
  * Real time text related function
    linphone_chat_message_get_char() now will always return the
    new line character, which wasn't the case before if the
    get_char() was done after the composing callback was triggered
    for this character.
  * linphone_core_interpret_url() will unescape characters first if
    possible if only a username is given as input parameter.
  * linphone_chat_message_cancel_file_transfer() no longer deletes
    the file for outgoing messages.
  * magic search result created from filter now applies the
    international prefix of the default proxy config if possible.
  * To improve performance file transfer progress callback will be
    at most notified 100 times.
  * Deprecate linphone_core_audio_route_changed() that was
    introduced in 4.4, to fix audio issues
  * when switching audio to some low sample rate Bluetooth devices
    It is now handled internally.
  * Internal refactoring of management of locally played tones, in
    order to fix race conditions.
  * Magic search bar not looking in all friends lists.
  * Error IMDN in LIME chat rooms not properly sent.
  * Chat message lost during attachment auto download if Core
    stopped during the process.
  * Windows tests.
  * Name of MediaCodec encoder and decoder filters in H264Helper
    Java class.
  * Both FileContent and FileTransferContent being present in
    linphone_chat_message_get_contents() list until upload is
    finished.
- Move grammar to liblinphone-data
  * boo#1181746
* Tue Oct  6 2020 Benjamin Greiner <code@bnavigator.de>
- Force linking to libsoci_sqlite3
  * boo#1140595 (comment 15)
  * linphone-link-soci-sqlite3.patch
* Wed Jul 29 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.4.0:
  * See https://gitlab.linphone.org/BC/public/liblinphone/blob/4.4.0/CHANGELOG.md
* Wed Apr 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.3.1:
  * No changelog available.
- Update the licence: it is now GPLv3+.
- Rebase linphone-build-readline.patch,
  linphone-fix-pkgconfig.patch.
- Drop linphone-fix-gtkui-build.patch.
- Remove outdated elements from the spec file.
* Sun Jun  9 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort file list to make build reproducible
  (boo#1041090)
* Tue Aug 14 2018 sor.alexei@meowr.ru
- Change the build dependency from udev to libudev-devel.
- Change the RPM group to the more appropriate and precise
  Productivity/Telephony/SIP/Clients.
* Wed Feb 21 2018 sor.alexei@meowr.ru
- Add linphone-build-readline.patch: Add the ability to compile
  with readline to the build system.
- Build with the readline support.
* Mon Feb 19 2018 sor.alexei@meowr.ru
- Revert back to Python2: building with Python3 has regressions
  (boo#1077857).
* Fri Jan 19 2018 sor.alexei@meowr.ru
- Switch to building with Python3.
* Thu Nov  9 2017 olaf@aepfle.de
- Use linphone_gtkui conditionally everywhere
* Mon Oct 30 2017 olaf@aepfle.de
- Use build conditional for C++ bindings also in liblinphone-devel
* Wed Oct  4 2017 olaf@aepfle.de
- Add build condtionally for C++ bindings to fix build in Leap
- Remove build conditionally for ffmpeg
- Remove build conditionally for ldap
- Remove unused BuildRequires for disabled rootca download
* Fri Sep 22 2017 sor.alexei@meowr.ru
- Provide liblinphone for the liblinphone-lang package.
* Sun Sep 10 2017 sor.alexei@meowr.ru
- Fix the licence: there are GPL-3.0 licensed files.
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 3.12.0:
  * C++ and C# bindings.
  * Account Creator plugin API.
  * Xamarin support.
- Switch from building with autotools to cmake.
- Add linphone-fix-pkgconfig.patch: Install linphone.pc.
- Add linphone-fix-gtkui-build.patch: Fix building of GtkUI.
- Disable the deprecated GTK+ UI for openSUSE Leap 15.x and newer,
  but keep for older as the Qt inteface requires Qt 5.9+.
- Split libraries, data files and the CLI.
- Enable building C++ bindings.
- Add baselibs.conf.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 3.11.1 (changes since 3.10.2):
  * Security vulnerability fix concering TLS. The common name of
    certificats delivered by SIP proxies were not compared with
    their host name.
  * Fix a bug in the P2P presence system. Unchecking
    "Allow this contact to see my presence" check box in contact
    editing view had no any effect. Then it was not possible to
    hide presence informations to a contact once it had been
    allowed to see it.
  * Performance improvments of the presence list feature.
  * IM Encription Engine: Abstraction for messaging encription
    protocols.
  * A bug fix in Autotools scripts.
* Wed Feb 22 2017 fcrozat@suse.com
- Ensure %%icon_theme_cache_* macros are called in post/postun
  scripts.
* Thu Sep 29 2016 sor.alexei@meowr.ru
- Update to version 3.10.2 (changes since 3.9.1):
  * Add lime_experimental_feature: set to 1 in .linphonerc [GtkUi]
    to show the Lime menu in the graphical user interface.
    Caution: Experimental.
  * Video conference support through a conference server (SDK only).
  * Disable dummy STUN packets sending when ICE is activated.
  * Signal AVPF support as AVP: Enable rtcp feedback on RTP/AVP by
    default.
  * Add linphone daemon.
  * gtk: Show links to files received in chat by file transfer.
  * gtk: Debug window now stores "scroll to end" preference.
  * gtk: Add button to take screenshot of video call.
  * gtk: Fix busy presence not displayed in red.
  * Fix Bad SDP when no audio codec has been enabled.
  * Fix DTMF RFC2833 event always goes up in the same
    LinphoneCoreListener.
  * Fix linphone python version compilation - fixing vcards.
* Mon Aug  8 2016 olaf@aepfle.de
- Use ffmpeg buildconditional also in devel pkg
* Thu Aug  4 2016 olaf@aepfle.de
- Build with ffmpeg unconditionally
- Remove unused gl,glew,vpx,xv
* Tue Jun 28 2016 bwiedemann@suse.com
- require a recent enough libbellesip0 package to run (bnc#957599)
* Thu Nov 19 2015 mpluskal@suse.com
- Update to 3.9.1
  * Fix crash when recording video calls with the VP8 codec
  * Fix H.264 codec support in Mac OS X package
  * Fix translation of account assistant
  * Bug fixes
- Make build more verbose
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 3.9.0:
  * Video recording of calls in MKV format.
  * Clickable URLs in chat view.
  * Add buttons to change the record and playback volumes during a
    call.
  * Add button to start chatting without having to create a contact
    first.
  * Some icon changes.
  * Call logs now stored in database.
  * Bug fixes.
* Mon Sep 21 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg to fix build in PMBS
* Tue Sep  8 2015 sor.alexei@meowr.ru
- Update to 3.8.5 (changes since 3.8.0):
  + Application level improvements:
  * Auto-answer ability.
  * Add support of the StatusNotifierItem standard (modern
    GNU/Linux status icons).
  * Auto-answering can be set through the preferences panel.
  * Fix crash at the end of the audio assistant.
  * Fix crash when configuring a remote provisioning.
  * Fix regretion in the codec view. Codec which are not usable
    because bandwitch limits are to low were not grayed anymore.
  * Bug fixes.
  * Add translation for 'Arabic' and 'Turkish' items in the
    language selection list
  + Liblinphone level improvements:
  * Fix audio bug with OPUS codec.
  * Fix ICE corner case not properly handled and resulting bad
    final ice status.
  * Update shared library ABI version to 7 (it should had been
    done in 3.8.0).
  * Bug fixes.
  * Add a built-in XMLRPC client. Linphone does not depend on
    libsoup anymore.
- Build with video support outside PMBS for openSUSE Leap 42.1
  and newer (where ffmpeg is available).
* Sun Apr  5 2015 fisiu@opensuse.org
- Enable ldap support.
* Sat Mar 28 2015 sor.alexei@meowr.ru
- Regenerate configure with autotools to solve build problems in
  some cases.
- Remove redefinition of GenericName in desktopfile.
* Sun Mar 15 2015 sor.alexei@meowr.ru
- Update to 3.8.0:
  + Application level improvements:
  * The video window has now controls in order to switch
    fullscreen mode and terminate call.
  * The out of call video preview feature (to test camera) is
    moved into the settings and is no longer linked to the in-call
    video preview feature.
  * Add an assistant to help users to set audio/video parameters.
  * Some ergonomics improvments (checkbox to set random port for
    UDP and TCP, ...).
  * Lots of updated translations. Arabic translation has been
    added.
  * Experimental feature: play an MKV file by drag-and-dropping
    it on the video call window.
  + Liblinphone level improvements:
  * Support for RTP/AVPF (RFC4585) for video streams, allowing fast
    transmission error recovery with VP8 codec only.
  * API enhancements, most objects can be ref-counted.
  * Add some getter funtctions to the call information API.
  * Add a function in the API to accept early-media calls.
  * Add a function to set the SIP transport timeout.
  * Add a function to change adaptive rate algorithm at runtime.
  * Add support of file transfer.
  * Call video recording feature, in mkv format (H264 streams only
    for the moment).
  * Call playing feature: play an MKV file and send the audio/video
    stream through a call.
  * Local player API. Play WAV and MKV file and display video on a
    specified window display.
  * A wrapper for Python has been made.
  * Support of multicast IP addresses.
  * Support of incoming UPDATEs within dialog (RFC3311).
  * Support of SRTP by using packages from distributions.
- Spec cleanup.
* Fri Aug 15 2014 fisiu@opensuse.org
- Update to 3.7.0:
  Application level improvements:
  * It is now possible to configure multiple proxy accounts with different
    transports (UDP, TCP, TLS)
  * can work with IPv6 and IPv4 simultaneously
  * User can choose video rendering method on Linux
  * Video HD formats support added, leveraging on multiple cores for encoding
    if available
  * Keyboard can be used for DTMF input
  * Faster and higly responsive UI thanks to fully asynchronous operation of
    the liblinphone.
  * Addon of opus codec
  * Possibility to specify a remote provisionning http URI for configuration
  * LDAP search integration for Linux and MacOSX
  * is-composing notification in chat area
  Liblinphone level improvements thanks to new "belle-sip" SIP stack:
  * multiple SIP transports simultaneously now allowed
  * IP dual stack: can use IPv6 and IPv4 simultaneously
  * fully asynchronous behavior: no more lengthly DNS or connections
  * +sip.instance parameter (RFC5626)
  * alias parameter (RFC5923)
  * better management of network disconnections
  * SIP/TLS handled through lightweighted polarssl library (instead of
    openssl)
  * SIP transaction state machines improved (RFC6026)
  * Privacy API (RFC3323, RFC3325)
  * Full support of rich presence in (RFC4480)
  * Better handling of sips scheme in URIs.
  * Messaging: support of is-composing (RFC3994)
  * Call transfer fixes in error cases
  * Add API for managing SIP SUBSCRIBES/NOTIFY/PUBLISH (linphonecore/event.h)
  * bugfixes
* Tue Feb 11 2014 zaitor@opensuse.org
- Version pkgconfig(libzrtpcpp) BuildRequires to resolve build for
  13.2 and newer.
* Thu Jun 20 2013 fisiu@opensuse.org
- Update to 3.6.1:
  * UI:
  * new friend list and chat messaging UI
  * enhanced call history
  * call and conference audio recording
  * persistent chat history
  * DSCP settings for SIP and RTP
  * display of call statistics (when clicking on the quality indicator bar)
  * Core:
  * ICE for efficient RTP exchange
  * fix bug in zRTP support (upgrade required)
  * call recording
  * uPnP
  * call statistics
  * adaptive bitrate control improvements
  * faster call quality indicator feedback
  * DSCP settings for SIP and RTP
  * detailed call statistics feedback API
- Drop linphone-ffmpeg.patch and linphone-v4l.patch: they were for
  shipped mediastreamer but we're using external one.
- Spec cleanup.
* Sat Mar  2 2013 seife+obs@b1-systems.com
- fix build with automake-1.13.1
* Mon Nov 12 2012 mailaender@opensuse.org
- add libsrtp and libzrtpcpp as build dependency
* Sat Oct 27 2012 mailaender@opensuse.org
- use external libortp and mediastreamer2
* Fri Oct 12 2012 vadimuzzz@inbox.ru
- added video support (disabled by default), to enable need to rebuild "with video"
- modify patch linphone-v4l (ffmpeg API changed)
- added linphone-ffmpeg.patch (ffmpeg API changed)
* Mon May 21 2012 jengelh@inai.de
- Use BuildRequires: pkgconfig(gnutls) instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Tue May 15 2012 i@marguerite.su
- update to version 3.5.2
  * updated oRTP to 0.20.0
  * updated mediastreamer2 to 2.8.2
  * added ZRTP media encryption
  * added SILK audio codec
- modify patch linphone-v4l.
- drop applet sub-package. since no useful data.
* Thu Nov 24 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Thu Nov 24 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Jul 24 2011 seife+obs@b1-systems.com
- update to version 3.4.3, see NEWS file for detailed changelog,
  obsoletes patches
- build / packaging improvements:
  - remove build date from binaries, use the tarball's timestamp
  - verbose build for rpmlint checking
  - add AUTHORS, NEWS, COPYING files
  - fix rpm group of devel package
  - add alsa-devel and libgsm-devel buildrequires
  - explicitly enable alsa, ssl, rsvp, ipv6
* Tue Jul 12 2011 cwh@novell.com
- fixing 11.4 build
* Thu Jul  7 2011 idonmez@novell.com
- Add linphone-v4l-2.6.38.patch: use new v4l interface
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Jan 16 2011 seife+obs@b1-systems.com
- Patch up to current git state of branch 3.3.x. Unfortunately,
  the git history is not helpful to create a changelog.
  But this fixes bnc#664808.
* Wed Dec 29 2010 aj@suse.de
- Run spec file through spec-cleaner.
- Remove build dependencies on libgnomeprintui-devel and
  libwnck-devel, they are not needed.
* Thu Nov 11 2010 coolo@novell.com
- own parent directory for gnome-panel
* Wed Aug 11 2010 ro@suse.de
- update to linphone-3.3.2
  * enhancements made to presence support (SIP/SIMPLE)
  * be nat friendly using OPTIONS request and using received,rport from
  responses.
  * use stun guessed ports even if symmetric is detected (works with freeboxes)
  * improve bitrate usage of speex codec
  * allow speex to run with vbr (variable bit rate) mode
  * add speex/32000 (ultra wide band speex codec)
  * answer empty SIP INFO requests
  * reverse order of call logs
  * optimize video display
  * manual or automatic network connectivity management (so that REGISTERs
  are only sent when network is up or refreshed when it comes back)
  * new in-call layout
  * new idle view with two buttons
  * ability to dial the number from dialpad
  * improve local IP address detection when having multiple networks (ex: VPNs)
  * use proxy's received and rport params from via in Contact header when possible
  * add an option to ask linphone to place a call, whenever an instance is already running or not:
  should be useful for starting calls from a web browser recognizing the 'sip:' uri scheme.
  * don't show ffmpeg codecs when encoder are disabled in ffmpeg library.
  * update theora default settings to match performance of 1.0 release.
  * linphone can now send large video pictures: up to SVGA, configurable via the user interface
  * automatic rescaling of the video windows to the video size of incoming stream
  * enable lookups of SRV records
  * new 'linphonecsh' program to send commands to a linphonec running as daemon using unix sockets or tcp.
  - tons of bugfixes, please see NEWS file for details
- update to version 3.0.0
  * new graphical interface based on Glade/Gtk
  * systray icon
  * STUN working for RTP
  * accurate bandwidth management (to let video occupy all remaning bandwidth)
  * new H264 plugin based on x264 (msx264)
  * automatic call hangup upon media transmission faillure
* Wed Dec  2 2009 coolo@novell.com
- update patch to fix build
* Mon May 25 2009 hvogel@suse.de
- Translations update
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Wed Oct 22 2008 hvogel@suse.de
- get rid of autoreconf call to make it build again
* Fri Apr 18 2008 hvogel@suse.de
- Hide online help button, we dont have an XML file to pass to
  gnome_help_display so its of no use.
* Thu Apr  3 2008 hvogel@suse.de
- update to version 2.1.1
  * Clean up commands 'nat', 'stun' and 'firewall' to be
    more intuitive
  * Upgrade to newest gettext
- fix some rpmlint warnings
- get rid of libtool archives
* Fri Jan 18 2008 mskibbe@suse.de
- portate to new libosip version
- fix typo in linphone-1.3.0.patch
* Wed Jan 16 2008 mskibbe@suse.de
- update to version 2.0.1 which
  o use new (eX)osip version
  o Clean ANSI/C vs. ANSI/C++ differences
  o fix a lot of small bugs
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Sep  4 2007 mskibbe@suse.de
- update to versin 1.7.1:
  * arts sound input/output
  * improved sound latency with alsa
  * alsa support works with dmix/dsnoop
  * fix a lot of bugs
* Tue Jun 19 2007 mskibbe@suse.de
- disable Werror
* Wed May 16 2007 ro@suse.de
- use libosip2-devel in buildrequires
* Thu Mar  8 2007 mskibbe@suse.de
- add missing directories
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Feb  8 2007 mskibbe@suse.de
- fix build problems
* Tue Jan 16 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Aug 10 2006 mskibbe@suse.de
- update to version 1.3.0 which includes
  o a lots of improvements in linphonec (see strk 's Changelogs below)
  o telephone event problem with sipomatic.
  o updated cz translation.
  o fix bugs around addressbook.
  o video support with H263-1998/RFC2429 nearly clean.
  o added timeout for incoming calls
* Sat Feb 18 2006 gekker@suse.de
- Update .desktop file for UI team
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 hvogel@suse.de
- Update to version 1.2.0
* Fri Nov 11 2005 hvogel@suse.de
- care about return values. Added
  * linphone-returnchecks.patch
* Wed Oct  5 2005 hvogel@suse.de
- update to version 1.1.0 drop
  * linphone-manual.patch
  * linphone-cs_cz.patch
  * linphone-cs_cz-fixes.patch
  * linphone-configure.patch
* Fri Sep  9 2005 hvogel@suse.de
- update cz translation
* Fri Jul  8 2005 mmj@suse.de
- fix more prototypes
* Tue Jul  5 2005 mmj@suse.de
- fix unitialized vars
- fix prototypes
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Wed Apr 20 2005 hvogel@suse.de
- fix bonobo server file to include an icon
- fix desktop file to have both Name and GenericName
- fix return values
* Tue Mar 22 2005 max@suse.de
- Update to final 1.0.0 version, which is more stable (#74253).
* Tue Mar 22 2005 sbrabec@suse.cz
- Moved applet bonobo server description to linphone-applet.
* Tue Mar 22 2005 coolo@suse.de
- split the gnome applet into an own package (#74199)
* Thu Mar 17 2005 hvogel@suse.de
- fix desktop file
* Tue Feb 15 2005 ro@suse.de
- added czech translations by Klara Cihlarova
* Thu Feb  3 2005 hvogel@suse.de
- add the manual so the manual button works
* Mon Jan 24 2005 ro@suse.de
- mark as NoSource (ffmpeg is there but unused).
* Wed Jan 19 2005 ro@suse.de
- update to 1.0.0pre6
- fixed more compiler warnings
* Sun Nov 14 2004 ro@suse.de
- fix another compile warning
* Tue Nov  9 2004 ro@suse.de
- update to 1.0.0pre4
- split patch in pieces
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed applet broken by bad libdir usage.
- Fixed libexecdir for bi-arch (#47050).
* Wed Jul 28 2004 ro@suse.de
- update to 1.0.0pre1
* Wed May 19 2004 ro@suse.de
- update to 0.12.2
- fix some compiler warnings
* Tue Feb  3 2004 ro@suse.de
- use -fno-strict-aliasing
* Wed Jan 21 2004 ro@suse.de
- update to 0.12.1
- make it build
* Mon Oct 20 2003 ro@suse.de
- don't build as root
* Sat Aug 23 2003 ro@suse.de
- update to 0.12.0
* Tue Jul 29 2003 ro@suse.de
- install it all to /opt/gnome
* Thu Jul 17 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
- Added gnome-panel to neededforbuild.
* Wed Jun 11 2003 ro@suse.de
- fix desktop file path
* Wed Jun 11 2003 ro@suse.de
- libtoolize in osipua subdirectory for proper soname
* Tue Jun 10 2003 ro@suse.de
- created package (version 0.11.0)
- use system speex library
